@@ -28,8 +28,10 @@ hescrc <- function(tfrep, tfspec = numeric(dim(tfrep)[2]), grida = 10,
 #	tfspec: additional potential (coming from learning the noise)
 #       grida : window of a
 #       gridb : window of b
-#       pct : the percent number of points in window 2*grida and 2*gridb to select histogram
-#       count : the maximal number of repetitive selection, if location was chosen before
+#       pct : the percent number of points in window 2*grida and
+#             2*gridb to select histogram
+#       count : the maximal number of repetitive selection, if location
+#               was chosen before
 #       iteration: number of iterations
 #       rate: initial value of the temperature
 #       seed: initialization for random numbers generator
@@ -39,8 +41,8 @@ hescrc <- function(tfrep, tfspec = numeric(dim(tfrep)[2]), grida = 10,
 #	chain: if set to TRUE, chains the ridges.
 #	flag.temp: if set to TRUE, keeps a constant temperature.
 #       linfflag: if set to TRUE, the line segments oriented to the
-#                 where the climber will move freely at the block is shown in 
-#                 image   	
+#                 where the climber will move freely at the block is
+#                 shown in image   	
 #       
 #      output:
 #      -------
@@ -66,7 +68,7 @@ hescrc <- function(tfrep, tfspec = numeric(dim(tfrep)[2]), grida = 10,
      sqmodulus[,k] <- sqmodulus[,k] - tfspectrum[k]
    image(sqmodulus)
 
-  # number of grid size
+   ## number of grid size
    nbx <- as.integer(sigsize/gridb)
    nby <- as.integer(nscale/grida)
    if((sigsize/gridb - nbx) > 0) nbx <- nbx + 1
@@ -74,9 +76,10 @@ hescrc <- function(tfrep, tfspec = numeric(dim(tfrep)[2]), grida = 10,
 
    nbblock <- nbx * nby
 
-  # first two locations at each block stores the lower-left corner of the block
-  # followed by the locations of up-right corner and by the negative values
-  # of hessian matrix from xx, xy, yx, and yy at the last.
+   ## first two locations at each block stores the lower-left corner
+   ## of the block followed by the locations of up-right corner and by
+   ## the negative values of hessian matrix from xx, xy, yx, and yy at
+   ## the last.
 
    tst <- matrix(0, 8, nbblock)
    dim(tst) <- c(nbblock * 8,1)
@@ -84,31 +87,28 @@ hescrc <- function(tfrep, tfspec = numeric(dim(tfrep)[2]), grida = 10,
    dim(sqmodulus) <- c(sigsize * nscale, 1)
 
    z <- .C("Shessianmap",
-	as.double(sqmodulus),
-        as.integer(sigsize),
-	as.integer(nscale),
-	ublock = as.integer(nbblock),
-	as.integer(gridb),
-	as.integer(grida),
-	tst =as.single(tst))
-
+           as.double(sqmodulus),
+           as.integer(sigsize),
+           as.integer(nscale),
+           ublock = as.integer(nbblock),
+           as.integer(gridb),
+           as.integer(grida),
+           tst =as.single(tst),
+           PACKAGE="Rwave")
   
    tst <- z$tst
    dim(tst) <- c(8, nbblock)
 
-  # actual number of block 	
-
+   ## actual number of block 	
    ublock <- z$ublock
 
-  # principle component analysis and calculate the direction of each block
+   ## principle component analysis and calculate the direction of each block
+   pcamap <- matrix(1,sigsize,nscale)
 
-
-  pcamap <- matrix(1,sigsize,nscale)
-
-  # first eigenvector of a block
+   ## first eigenvector of a block
    eigv1 <- matrix(0,ublock,2)
 
-   # to draw eigenvector in a block 
+   ## to draw eigenvector in a block 
    if(lineflag) {	
      lng <- min(grida, gridb)
      oldLng <- lng
@@ -130,23 +130,24 @@ hescrc <- function(tfrep, tfspec = numeric(dim(tfrep)[2]), grida = 10,
         eig<- eigen(ctst)
 
 	
-#	cat("first eig = ",eig$values[1]," ratio in eigenvalues =  ",abs(eig$values[1]/eig$values[2])," \n")
+        ## cat("first eig = ",eig$values[1]," ratio in eigenvalues =
+        ## ",abs(eig$values[1]/eig$values[2])," \n")
 
-        # eigen vector 1
+        ## eigen vector 1
         eigv1[j,] <- eig$vector[,1]
 
 
-        # shifted center position of a block
+        ## shifted center position of a block
 	if(lineflag) {
           centerx <- as.integer((left + right)/2)
           centery <- as.integer((down + up)/2)
 	}
 
-        # theta of the eigen vector 1; -pi < theta <= pi
+        ## theta of the eigen vector 1; -pi < theta <= pi
 
         theta <- atan((eigv1[j,])[2],(eigv1[j,])[1])
 
-        # along x : denote 1 in the hesmap
+        ## along x : denote 1 in the hesmap
 
         if(((theta <= pi/8) && (theta > -pi/8)) ||
 	   (theta > 7*pi/8 || theta <= -7*pi/8)) {
@@ -168,7 +169,7 @@ hescrc <- function(tfrep, tfspec = numeric(dim(tfrep)[2]), grida = 10,
 	}
 	}
 
-        # along x=y : denoted as 4 in hesmap
+        ## along x=y : denoted as 4 in hesmap
 
         if(((theta > pi/8) && (theta <= 3*pi/8)) ||
 	   ((theta > -7*pi/8) && (theta <= -5*pi/8))) {
@@ -195,7 +196,7 @@ hescrc <- function(tfrep, tfspec = numeric(dim(tfrep)[2]), grida = 10,
 	}
 
 
-        # along y : as 3 in hesmap
+        ## along y : as 3 in hesmap
 
         if(((theta > 3*pi/8) && (theta <= 5*pi/8)) ||
 	   ((theta > -5*pi/8) && (theta <= -3*pi/8))) {
@@ -219,7 +220,7 @@ hescrc <- function(tfrep, tfspec = numeric(dim(tfrep)[2]), grida = 10,
 	}
 
 
-        # along x=-y : as 2 in hesmap
+        ## along x=-y : as 2 in hesmap
 
         if(((theta > 5*pi/8) && (theta <= 7*pi/8)) ||
 	   ((theta > -3*pi/8) && (theta <= -pi/8))) {
@@ -249,28 +250,29 @@ hescrc <- function(tfrep, tfspec = numeric(dim(tfrep)[2]), grida = 10,
 	  if(lineflag) oldLng <- Lng
    }
 
-#   if(lineflag==F) image(pcamap)	
+   ##   if(lineflag==F) image(pcamap)	
 
-# From the following on, it is similar to the process of crazy climbers ....
+   ## From the following on, it is similar to the process of crazy climbers...
 
    beemap <- matrix(0,sigsize,nscale) 
    dim(beemap) <- c(nscale * sigsize, 1)
    dim(pcamap) <- c(nscale * sigsize, 1)
      
    z <- .C("Spca_annealing",
-        as.double(sqmodulus),
-        beemap= as.double(beemap),
-	as.integer(pcamap),
-        as.single(rate),
-	as.integer(sigsize),
-        as.integer(nscale),
-        as.integer(iteration),
-	as.integer(seed),
-        as.integer(bstep),
-        as.integer(nbclimb),
-	as.integer(flag.int),
-	as.integer(chain),
-	as.integer(flag.temp))
+           as.double(sqmodulus),
+           beemap= as.double(beemap),
+           as.integer(pcamap),
+           as.single(rate),
+           as.integer(sigsize),
+           as.integer(nscale),
+           as.integer(iteration),
+           as.integer(seed),
+           as.integer(bstep),
+           as.integer(nbclimb),
+           as.integer(flag.int),
+           as.integer(chain),
+           as.integer(flag.temp),
+           PACKAGE="Rwave")
 
    beemap <- z$beemap
    dim(beemap) <- c(sigsize, nscale)
